#!/usr/bin/env python3

import sys
import os
import stumpy
import numpy as np
import math

def euclidean(a, b):
    distance = 0
    for i in range(len(a)):
        t = (a[i] - b[i]) ** 2
        distance = distance + t
    return math.sqrt(distance)

if len(sys.argv) != 3:
	sys.exit("Not enough arguments!")

size = int(sys.argv[1])
# Approximately, how many data points might be found in a pattern
windowSize = int(sys.argv[2])

print("Size", size, "Query", windowSize)

# Create a time series with random data
# Original time series
original = np.random.rand(size)

# V1
# Reverse time series
v1 = original[::-1]
mpdist = stumpy.mpdist(original, v1, m=windowSize)

print("---- v1")
ed = euclidean(original, v1)
print("MPdist: %.4f Euclidean: %.4f" % (mpdist, ed))

# V2
# Half1 + Half2 -> Half2 + Half1
newarr = np.array_split(original, 2)
v2 = np.append(newarr[1], newarr[0])
mpdist = stumpy.mpdist(original, v2, m=windowSize)

print("---- v2")
ed = euclidean(original, v2)
print("MPdist: %.4f Euclidean: %.4f" % (mpdist, ed))

# V3
# Remove last n elements
a1 = np.resize(original, original.size - windowSize)
# Get last n elements
a2 = original[-windowSize:]
v3 = np.append(a2, a1)
mpdist = stumpy.mpdist(original, v3, m=windowSize)

print("---- v3")
ed = euclidean(original, v3)
print("MPdist: %.4f Euclidean: %.4f" % (mpdist, ed))

# V4
# Remove last n elements
a1 = np.resize(original, original.size - windowSize)
a2 = np.random.rand(windowSize)
v4 = np.append(a1, a2)
mpdist = stumpy.mpdist(original, v4, m=windowSize)

print("---- v4")
ed = euclidean(original, v4)
print("MPdist: %.4f Euclidean: %.4f" % (mpdist, ed))

# V5
v5 = np.array(original, copy=True)
np.random.shuffle(v5)
mpdist = stumpy.mpdist(original, v5, m=windowSize)

print("---- v5")
ed = euclidean(original, v5)
print("MPdist: %.4f Euclidean: %.4f" % (mpdist, ed))
